@@ -66,7 +66,7 @@ impl GetChangesForNewContract {
     fn create_template_test(&mut self) {
         let content = format!(
             r#"
-import {{ Clarinet, Tx, Chain, Account, types }} from 'https://deno.land/x/clarinet@v0.6.0/index.ts';
+import {{ Clarinet, Tx, Chain, Account, types }} from 'https://deno.land/x/clarinet@v0.10.0/index.ts';
 import {{ assertEquals }} from 'https://deno.land/std@0.90.0/testing/asserts.ts';
 
 Clarinet.test({{
@@ -119,7 +119,7 @@ Clarinet.test({{
             comment: format!("Adding contract {} to Clarinet.toml", self.contract_name),
             path,
             contracts_to_add,
-            links_to_add: vec![],
+            requirements_to_add: vec![],
         };
         self.changes.push(Changes::EditTOML(change));
     }
